<?php
/*
* Smarty plugin
* -------------------------------------------------------------
* File:     block.loop.php
* Type:     block function
* Name:     loop
* Purpose:  loops over a piece of template content x amount of times
* -------------------------------------------------------------
*/
function smarty_block_loop($params, $content, &$smarty) {
	  //check if the block has data
	  if (is_null($content)) {
	    return;
	  }
	  //check if the start parameter is set
	  if (strlen($params['start']) == 0 || !is_numeric($params['end'])) {
	    $smarty->trigger_error("assign: missing 'start' parameter or is ".
	      "not a number");
	    return;
	  }
	  //check if the end parameter is set
	  if (strlen($params['end']) == 0 || !is_numeric($params['end'])) {
	    $smarty->trigger_error("assign: missing 'end' parameter or is ".
	      "not a number");
	    return;
	  }
	  //check if the increment is set. If not, default is +1
	  if (empty($params['increment']) || !is_numeric($params['increment'])) {
	    $params['increment'] = 1;
	  }
	 
	  //do the loop!
	  $data = '';
	  //check if we're incrementing or decrementing
	  if ($params['end'] > $params['start']) {
	    //incrementing, check $increment value is positive
	    if ($params['increment'] <= 0) {
	      $smarty->trigger_error("assign: increment cannot be negative or ".
	        "zero when 'start' is less than 'end'");
	      return;
	    }
	    for ($x=$params['start'];$x < $params['end'];$x=$x+$params['increment']) {
	     
	      $data .= str_replace('$'.$params["assign"],$x,$content);
	    }
	  } else {
	    //decrementing, check $increment value is negative
	    if ($params['increment'] <= 0) {
	      $smarty->trigger_error("assign: increment cannot be positive or ".
	        "zero when 'start' is greater than 'end'");
	      return;
	    }
	    for ($x=$params['start'];$x > $params['end'];$x=$x+$params['increment']) {
	      $data .= str_replace('$'.$params["assign"],$x,$content);
	    }
	  }
	  //return the data
	  return $data;
} //end smarty_block_loop
?>